#
# spec file for package buildpacks-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name pack

Name:           buildpacks-cli
Version:        0.36.4
Release:        1.1
Summary:        CLI for building apps using Cloud Native Buildpacks
License:        Apache-2.0
URL:            https://github.com/buildpacks/pack
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh
Provides:       pack = %{version}
Conflicts:      allegro44-tools
#
# vendor/github.com/gdamore/tcell/v2/attr.go:32:25: cannot use 1 << 31 (untyped
# int constant 2147483648) as AttrMask value in constant declaration
# (overflows)
ExcludeArch:    %{ix86} armv7hl

%description
pack makes it easy for...

* App Developers to use buildpacks to convert code into runnable images.
* Buildpack Authors to develop and package buildpacks for distribution.
* Operators to package buildpacks for distribution and maintain applications.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X github.com/buildpacks/pack.Version=%{version}" \
   -o bin/%{executable_name} ./cmd/%{executable_name}

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Sat Jan 18 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.36.4:
  * implementing logic for adding tag suffix
  * fixing formatting issue
  * WIP - adding a new flag --append-image-name-suffix to append
    [os]-[arch]-[variant] to the image name when pushing a
    multi-arch buildpack or builder
  * removing additional string matching
  * Updating hardcoded error message handling when an image was not
    found in a registry by platform
* Mon Jan 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.36.3:
  * build(deps): bump the go-dependencies group across 1 directory
    with 7 updates
  * with the new go-git version, this issue was fixed
    https://github.com/go-git/go-git/pull/1050
  * build(deps): bump github.com/go-git/go-git/v5 from 5.12.0 to
    5.13.0
  * build(deps): bump anchore/scan-action from 5 to 6
  * build(deps): bump buildpacks/github-actions from 5.8.4 to 5.8.5
* Fri Dec 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.36.2:
  * Updating x/net library to v0.33.0
  * build(deps): bump buildpacks/github-actions from 5.8.3 to 5.8.4
  * build(deps): bump the go-dependencies group with 2 updates
* Wed Dec 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.36.1:
  * build(deps): bump the go-dependencies group with 2 updates
  * build(deps): bump the go-dependencies group with 7 updates
  * Correct wording for `buildpack new` targets flag
  * build(deps): bump the go-dependencies group across 1 directory
    with 4 updates
  * build(deps): bump buildpacks/github-actions from 5.8.1 to 5.8.3
  * acceptance tests on arm64
* Wed Nov 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.36.0:
  * Emit a performance warning if containerd is enabled and we're
    exporting to the daemon
  * build(deps): bump the go-dependencies group across 1 directory
    with 9 updates
  * Cleanup after running acceptance tests
  * Try lifecycle binary 0.20.3
  * Bump lifecycle binary version also
  * Fixing lifecycle validation to use fully qualified names
  * Allow trusted builders by repo and tag
  * Use released lifecycle
  * build(deps): bump buildpacks/github-actions from 5.8.0 to 5.8.1
  * build(deps): bump buildpacks/github-actions from 5.7.4 to 5.8.0
  * build(deps): bump github.com/golang-jwt/jwt/v4 from 4.5.0 to
    4.5.1
  * Update actions
  * Pin BurntSushi/toml as test failures seem related to
    https://github.com/BurntSushi/toml/issues/417
  * FIXME: update lifecycle (to non-released version) so that we
    can bump docker
  * Bump deps and run tidy
  * Fix lint
  * Update go and run tidy
  * Use an existing directory instead of creating and deleting
    directories for each '--path' flag case to ensure no temp
    directories are left behind in case of a test failure.
  * build(deps): bump github.com/docker/docker
  * build(deps): bump buildpacks/github-actions from 5.5.4 to 5.7.4
  * avoid using os.MkdirTemp() to prevent test failures on macOS
  * rephrase the test description
  * Make it warns only when a local path with the same string as
    the specified image name exists
  * Don't warn about clear-env key while parsing buildpack.toml as
    this is actually expected.
  * Fix deletion of ephemeral builder
  * Improve descriptions for some test cases.
  * Add a test case for when the 'pack build' is called with the
    '--path' flag.
  * Make the 'pack build' command warn that the positional argument
    will not be treated as the source directory path.
  * handled case sensitivity
  * build(deps): bump anchore/scan-action from 3 to 4
  * Update image references in internal documents and ci settings
    to use fully qualified names.
  * Update references to lifecycle image to use fully qualified
    image name.
* Tue Aug  6 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.35.1:
  * Add retries for docker network remove
  * Fix ephemeral bridge network name for podman
  * Fix the helper script for testing the GitHub Action workflows
    on forked repositories.
  * Add ${{ matrix.suffix }} to the source tag for retagging.
  * Fix buildpacks#2237: consider /workspace as a sensitive dir
  * Support OCI layouts with
    application/vnd.oci.image.manifest.v1+json media type
  * Bump default lifecycle binary version from 0.19.6 to 0.20.0
  * Fix variable name.
  * Fix variable name.
  * Update the DEVELOPMENT.md
  * Fix variable name mismatch.
  * Finish the helper script for testing GitHub Action workflows on
    forked repository.
  * Add a draft helper script for testing GitHub Action workflows
    on forked repository.
  * Add --trust-extra-buildpacks option
  * Trust buildpacks in addition to those on the builder
* Mon Jul 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.35.0:
  * Log a warning (once) when PACK_VOLUME_KEY is unset and running in a container
  * Validate build image name
  * Try to fix wcow
  * Fix macos by not requiring real docker client for lifecycle execution unit tests
  * Launch build containers in a separate ephemeral Docker bridge network
  * Resolve some TODOs
  * Initial implementation (still has TODOs)
  * Warn if NOT --pull-policy=always in container
* Mon Jul 22 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package buildpacks-cli: CLI for building apps using Cloud
  Native Buildpacks
